@@ -118,6 +118,8 @@ class TreeNode:
             return self.children[0].evaluate().lower()
         elif self.token.ttype == TokenType.UPPER:
             return self.children[0].evaluate().upper()
+        elif self.token.ttype == TokenType.LEN:
+            return len(self.children[0].evaluate())
         elif self.token.ttype == TokenType.EQ:
             return self.children[0].evaluate() == self.children[1].evaluate()
         elif self.token.ttype == TokenType.NOTEQ:
@@ -405,8 +407,9 @@ class DDParser:
             or self.check_token(TokenType.NUMBER)
 
     def is_identifier_function(self):
-        return self.check_token(TokenType.UPPER)\
-            or self.check_token(TokenType.LOWER)
+        return self.check_token(TokenType.LOWER)\
+            or self.check_token(TokenType.UPPER)\
+            or self.check_token(TokenType.LEN)
 
     def is_equal_not_equal(self):
         return self.check_token(TokenType.EQ)\
